@@ -16,7 +16,7 @@ def table(data,index=False,head="l",value="l",v="|",h="-",dot="+"):
 		for z,x in enumerate(values):
 			for y in x:
 				if len(str(y))>headLen[z]:
-					headLen[z]=len(y)
+					headLen[z]=len(str(y))
 
 		if index:
 			sums = len(str(len(values[0])))
